@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -55,7 +55,7 @@ class CControllerProxyUpdate extends CController {
 				case self::VALIDATION_ERROR:
 					$response = new CControllerResponseRedirect('zabbix.php?action=proxy.edit');
 					$response->setFormData($this->getInputAll());
-					$response->setMessageError(_('Cannot update proxy'));
+					CMessageHelper::setErrorTitle(_('Cannot update proxy'));
 					$this->setResponse($response);
 					break;
 				case self::VALIDATION_FATAL_ERROR:
@@ -68,7 +68,7 @@ class CControllerProxyUpdate extends CController {
 	}
 
 	protected function checkPermissions() {
-		if ($this->getUserType() != USER_TYPE_SUPER_ADMIN) {
+		if (!$this->checkAccess(CRoleHelper::UI_ADMINISTRATION_PROXIES)) {
 			return false;
 		}
 
@@ -107,15 +107,20 @@ class CControllerProxyUpdate extends CController {
 		$result = DBend($result);
 
 		if ($result) {
-			$response = new CControllerResponseRedirect('zabbix.php?action=proxy.list&uncheck=1');
-			$response->setMessageOk(_('Proxy updated'));
+			$response = new CControllerResponseRedirect((new CUrl('zabbix.php'))
+				->setArgument('action', 'proxy.list')
+				->setArgument('page', CPagerHelper::loadPage('proxy.list', null))
+			);
+			$response->setFormData(['uncheck' => '1']);
+			CMessageHelper::setSuccessTitle(_('Proxy updated'));
 		}
 		else {
-			$response = new CControllerResponseRedirect(
-				'zabbix.php?action=proxy.edit&proxyid='.$this->getInput('proxyid')
+			$response = new CControllerResponseRedirect((new CUrl('zabbix.php'))
+				->setArgument('action', 'proxy.edit')
+				->setArgument('proxyid', $this->getInput('proxyid'))
 			);
 			$response->setFormData($this->getInputAll());
-			$response->setMessageError(_('Cannot update proxy'));
+			CMessageHelper::setErrorTitle(_('Cannot update proxy'));
 		}
 		$this->setResponse($response);
 	}
