@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,21 +29,22 @@ require_once dirname(__FILE__).'/include/page_header.php';
 
 // VAR	TYPE	OPTIONAL	FLAGS	VALIDATION	EXCEPTION
 $fields = [
-	'graphid' =>		[T_ZBX_INT, O_MAND, P_SYS,	DB_ID,		null],
-	'period' =>			[T_ZBX_INT, O_OPT, P_NZERO,	BETWEEN(ZBX_MIN_PERIOD, ZBX_MAX_PERIOD), null],
-	'stime' =>			[T_ZBX_STR, O_OPT, P_SYS,	null,		null],
-	'isNow' =>			[T_ZBX_INT, O_OPT, null,	IN('0,1'),	null],
-	'profileIdx' =>		[T_ZBX_STR, O_OPT, null,	null,		null],
-	'profileIdx2' =>	[T_ZBX_STR, O_OPT, null,	null,		null],
-	'updateProfile' =>	[T_ZBX_STR, O_OPT, null,	null,		null],
-	'width' =>			[T_ZBX_INT, O_OPT, null,	BETWEEN(CLineGraphDraw::GRAPH_WIDTH_MIN, 65535),	null],
-	'height' =>			[T_ZBX_INT, O_OPT, null,	BETWEEN(CLineGraphDraw::GRAPH_HEIGHT_MIN, 65535),	null],
-	'outer' =>			[T_ZBX_INT, O_OPT, null,	IN('0,1'),	null],
-	'onlyHeight' =>		[T_ZBX_INT, O_OPT, null,	IN('0,1'),	null]
+	'graphid' =>		[T_ZBX_INT,			O_MAND, P_SYS,	DB_ID,		null],
+	'from' =>			[T_ZBX_RANGE_TIME,	O_OPT, P_SYS,	null,		null],
+	'to' =>				[T_ZBX_RANGE_TIME,	O_OPT, P_SYS,	null,		null],
+	'profileIdx' =>		[T_ZBX_STR,			O_OPT, null,	null,		null],
+	'profileIdx2' =>	[T_ZBX_STR,			O_OPT, null,	null,		null],
+	'width' =>			[T_ZBX_INT,			O_OPT, null,	BETWEEN(CLineGraphDraw::GRAPH_WIDTH_MIN, 65535),	null],
+	'height' =>			[T_ZBX_INT,			O_OPT, null,	BETWEEN(CLineGraphDraw::GRAPH_HEIGHT_MIN, 65535),	null],
+	'outer' =>			[T_ZBX_INT,			O_OPT, null,	IN('0,1'),	null],
+	'onlyHeight' =>		[T_ZBX_INT,			O_OPT, null,	IN('0,1'),	null],
+	'legend' =>			[T_ZBX_INT,			O_OPT, null,	IN('0,1'),	null],
+	'widget_view' =>	[T_ZBX_INT,			O_OPT, null,	IN('0,1'),	null]
 ];
 if (!check_fields($fields)) {
 	exit();
 }
+validateTimeSelectorPeriod(getRequest('from'), getRequest('to'));
 
 /*
  * Permissions
@@ -68,19 +69,20 @@ else {
 /*
  * Display
  */
-$timeline = calculateTime([
-	'profileIdx' => getRequest('profileIdx', 'web.screens'),
+$timeline = getTimeSelectorPeriod([
+	'profileIdx' => getRequest('profileIdx'),
 	'profileIdx2' => getRequest('profileIdx2'),
-	'updateProfile' => (getRequest('updateProfile', '0') === '1'),
-	'period' => getRequest('period'),
-	'stime' => getRequest('stime'),
-	'isNow' => getRequest('isNow')
+	'from' => getRequest('from'),
+	'to' => getRequest('to')
 ]);
 
-CProfile::update('web.screens.graphid', $_REQUEST['graphid'], PROFILE_TYPE_ID);
-
 $graph = new CLineGraphDraw($dbGraph['graphtype']);
 
+if (getRequest('widget_view') === '1') {
+	$graph->draw_header = false;
+	$graph->with_vertical_padding = false;
+}
+
 // array sorting
 CArrayHelper::sort($dbGraph['gitems'], [
 	['field' => 'sortorder', 'order' => ZBX_SORT_UP],
@@ -117,8 +119,8 @@ foreach ($dbGraph['hosts'] as $gItemHost) {
 }
 
 $graph->setHeader(($hostName === '') ? $dbGraph['name'] : $hostName.NAME_DELIMITER.$dbGraph['name']);
-$graph->setPeriod($timeline['period']);
-$graph->setSTime($timeline['stime']);
+$graph->setPeriod($timeline['to_ts'] - $timeline['from_ts']);
+$graph->setSTime($timeline['from_ts']);
 
 $width = getRequest('width', 0);
 if ($width <= 0) {
@@ -130,7 +132,7 @@ if ($height <= 0) {
 	$height = $dbGraph['height'];
 }
 
-$graph->showLegend($dbGraph['show_legend']);
+$graph->showLegend(getRequest('legend', $dbGraph['show_legend']));
 $graph->showWorkPeriod($dbGraph['show_work_period']);
 $graph->showTriggers($dbGraph['show_triggers']);
 $graph->setWidth($width);
@@ -158,7 +160,7 @@ if ($min_dimentions['height'] > $graph->getHeight()) {
 
 if (getRequest('onlyHeight', '0') === '1') {
 	$graph->drawDimensions();
-	header('X-ZBX-SBOX-HEIGHT: '.$graph->getHeight());
+	header('X-ZBX-SBOX-HEIGHT: '.($graph->getHeight() + 1));
 }
 else {
 	$graph->draw();
