@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -45,6 +45,13 @@ class CTag extends CObject {
 	 */
 	protected $attrEncStrategy = self::ENC_ALL;
 
+	/**
+	 * Hint element for the current CTag.
+	 *
+	 * @var CSpan
+	 */
+	protected $hint = null;
+
 	public function __construct($tagname, $paired = false, $body = null) {
 		parent::__construct();
 
@@ -71,7 +78,6 @@ class CTag extends CObject {
 			$res .= ' '.$key.'="'.$value.'"';
 		}
 		$res .= '>';
-//		$res .= ($this->paired) ? '>' : ' />';
 
 		return $res;
 	}
@@ -90,6 +96,11 @@ class CTag extends CObject {
 		$res = $this->startToString();
 		$res .= $this->bodyToString();
 		$res .= $this->endToString();
+
+		if ($this->hint !== null) {
+			$res .= $this->hint->toString();
+		}
+
 		if ($destroy) {
 			$this->destroy();
 		}
@@ -169,20 +180,20 @@ class CTag extends CObject {
 	 * @return CTag
 	 */
 	public function setHint($text, $span_class = '', $freeze_on_click = true, $styles = '') {
-		$this->addItem(
-			(new CSpan(
-				(new CSpan($text))->addClass('hint-box')
-			))->setAttribute('style', 'display: none;')
-		);
+		$this->hint = (new CDiv($text))
+			->addClass('hint-box')
+			->setAttribute('style', 'display: none;');
 
-		$this->onMouseover(
-			'hintBox.HintWrapper(event, this, "'.$span_class.'", "'.$styles.'");'
-		);
+		$this->setAttribute('data-hintbox', '1');
 
+		if ($span_class !== '') {
+			$this->setAttribute('data-hintbox-class', $span_class);
+		}
+		if ($styles !== '') {
+			$this->setAttribute('data-hintbox-style', $styles);
+		}
 		if ($freeze_on_click) {
-			$this->onClick(
-				'hintBox.showStaticHint(event, this, "'.$span_class.'", false, "'.$styles.'");'
-			);
+			$this->setAttribute('data-hintbox-static', '1');
 		}
 
 		return $this;
@@ -195,6 +206,12 @@ class CTag extends CObject {
 	 */
 	public function setMenuPopup(array $data) {
 		$this->setAttribute('data-menu-popup', $data);
+		$this->setAttribute('aria-expanded', 'false');
+
+		if (!$this->getAttribute('disabled')) {
+			$this->setAttribute('aria-haspopup', 'true');
+		}
+
 		return $this;
 	}
 
@@ -218,6 +235,11 @@ class CTag extends CObject {
 		return $this;
 	}
 
+	public function onKeyup($script) {
+		$this->addAction('onkeyup', $script);
+		return $this;
+	}
+
 	public function addStyle($value) {
 		if (!isset($this->attributes['style'])) {
 			$this->attributes['style'] = '';
@@ -256,6 +278,17 @@ class CTag extends CObject {
 		return $this->getAttribute('id');
 	}
 
+	/**
+	 * Remove ID attribute from tag.
+	 *
+	 * @return CTag
+	 */
+	public function removeId() {
+		$this->removeAttribute('id');
+
+		return $this;
+	}
+
 	/**
 	 * Sanitizes a string according to the given strategy before outputting it to the browser.
 	 *
@@ -289,4 +322,22 @@ class CTag extends CObject {
 	public function getEncStrategy() {
 		return $this->encStrategy;
 	}
+
+	/**
+	 * Set or reset element 'aria-required' attribute.
+	 *
+	 * @param bool $is_required  Define aria-required attribute for element.
+	 *
+	 * @return $this
+	 */
+	public function setAriaRequired($is_required = true) {
+		if ($is_required) {
+			$this->setAttribute('aria-required', 'true');
+		}
+		else {
+			$this->removeAttribute('aria-required');
+		}
+
+		return $this;
+	}
 }
