@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,10 +19,11 @@
 **/
 
 
-class CWarning extends CDiv {
+class CWarning extends Ctag {
 
 	public function __construct($header, $messages = [], $buttons = []) {
-		parent::__construct($header);
+		parent::__construct('output', true);
+		$this->addItem($header);
 		$this->addClass(ZBX_STYLE_MSG_BAD);
 		$this->addClass('msg-global');
 		if ($messages) {
