@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2020 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -69,7 +69,7 @@ class CConfigurationImport {
 			'groups' => ['createMissing' => false],
 			'hosts' => ['updateExisting' => false, 'createMissing' => false],
 			'templates' => ['updateExisting' => false, 'createMissing' => false],
-			'templateScreens' => ['updateExisting' => false, 'createMissing' => false, 'deleteMissing' => false],
+			'templateDashboards' => ['updateExisting' => false, 'createMissing' => false, 'deleteMissing' => false],
 			'applications' => ['createMissing' => false, 'deleteMissing' => false],
 			'templateLinkage' => ['createMissing' => false, 'deleteMissing' => false],
 			'items' => ['updateExisting' => false, 'createMissing' => false, 'deleteMissing' => false],
@@ -106,9 +106,9 @@ class CConfigurationImport {
 		$options['process_templates'] = (
 			!$options['templates']['updateExisting']
 			&& ($object_options
-				|| $options['templateScreens']['updateExisting']
-				|| $options['templateScreens']['createMissing']
-				|| $options['templateScreens']['deleteMissing']
+				|| $options['templateDashboards']['updateExisting']
+				|| $options['templateDashboards']['createMissing']
+				|| $options['templateDashboards']['deleteMissing']
 			)
 		);
 		$options['process_hosts'] = (!$options['hosts']['updateExisting'] && $object_options);
@@ -141,7 +141,6 @@ class CConfigurationImport {
 		$this->deleteMissingTriggers();
 		$this->deleteMissingGraphs();
 		$this->deleteMissingItems();
-		$this->deleteMissingApplications();
 
 		// import objects
 		$this->processApplications();
@@ -153,10 +152,13 @@ class CConfigurationImport {
 		$this->processGraphs();
 		$this->processImages();
 		$this->processMaps();
-		$this->processTemplateScreens();
+		$this->processTemplateDashboards();
 		$this->processScreens();
 		$this->processMediaTypes();
 
+		// Missing applications should be deleted after new application changes are done to all inherited items.
+		$this->deleteMissingApplications();
+
 		return true;
 	}
 
@@ -179,7 +181,7 @@ class CConfigurationImport {
 		$iconMapsRefs = [];
 		$mapsRefs = [];
 		$screensRefs = [];
-		$templateScreensRefs = [];
+		$templateDashboardsRefs = [];
 		$macrosRefs = [];
 		$proxyRefs = [];
 		$hostPrototypesRefs = [];
@@ -322,6 +324,19 @@ class CConfigurationImport {
 						$templatesRefs[$template['name']] = $template['name'];
 					}
 				}
+
+				if ($discoveryRule['overrides']) {
+					foreach ($discoveryRule['overrides'] as $override) {
+						foreach ($override['operations'] as $operation) {
+							if ($operation['operationobject'] == OPERATION_OBJECT_HOST_PROTOTYPE
+									&& array_key_exists('optemplate', $operation)) {
+								foreach ($operation['optemplate'] as $template) {
+									$templatesRefs[$template['name']] = $template['name'];
+								}
+							}
+						}
+					}
+				}
 			}
 		}
 
@@ -456,33 +471,28 @@ class CConfigurationImport {
 			}
 		}
 
-		foreach ($this->getFormattedTemplateScreens() as $screens) {
-			foreach ($screens as $screen) {
-				$templateScreensRefs[$screen['name']] = $screen['name'];
+		foreach ($this->getFormattedTemplateDashboards() as $dashboards) {
+			foreach ($dashboards as $dashboard) {
+				$templateDashboardsRefs[$dashboard['name']] = $dashboard['name'];
 
-				if (!empty($screen['screenitems'])) {
-					foreach ($screen['screenitems'] as $screenItem) {
-						$resource = $screenItem['resource'];
+				if ($dashboard['widgets']) {
+					foreach ($dashboard['widgets'] as $widget) {
+						foreach ($widget['fields'] as $field) {
+							$value = $field['value'];
 
-						switch ($screenItem['resourcetype']) {
-							case SCREEN_RESOURCE_GRAPH:
-							case SCREEN_RESOURCE_LLD_GRAPH:
-								$hostsRefs[$resource['host']] = $resource['host'];
-								$graphsRefs[$resource['host']][$resource['name']] = $resource['name'];
-								break;
-
-							case SCREEN_RESOURCE_CLOCK:
-								if ($screenItem['style'] != TIME_TYPE_HOST) {
+							switch ($field['type']) {
+								case ZBX_WIDGET_FIELD_TYPE_ITEM:
+								case ZBX_WIDGET_FIELD_TYPE_ITEM_PROTOTYPE:
+									$hostsRefs[$value['host']] = $value['host'];
+									$itemsRefs[$value['host']][$value['key']] = $value['key'];
 									break;
-								}
-								// break; is not missing here
 
-							case SCREEN_RESOURCE_SIMPLE_GRAPH:
-							case SCREEN_RESOURCE_LLD_SIMPLE_GRAPH:
-							case SCREEN_RESOURCE_PLAIN_TEXT:
-								$hostsRefs[$resource['host']] = $resource['host'];
-								$itemsRefs[$resource['host']][$resource['key']] = $resource['key'];
-								break;
+								case ZBX_WIDGET_FIELD_TYPE_GRAPH:
+								case ZBX_WIDGET_FIELD_TYPE_GRAPH_PROTOTYPE:
+									$hostsRefs[$value['host']] = $value['host'];
+									$graphsRefs[$value['host']][$value['name']] = $value['name'];
+									break;
+							}
 						}
 					}
 				}
@@ -518,7 +528,7 @@ class CConfigurationImport {
 		$this->referencer->addIconMaps($iconMapsRefs);
 		$this->referencer->addMaps($mapsRefs);
 		$this->referencer->addScreens($screensRefs);
-		$this->referencer->addTemplateScreens($templateScreensRefs);
+		$this->referencer->addTemplateDashboards($templateDashboardsRefs);
 		$this->referencer->addMacros($macrosRefs);
 		$this->referencer->addProxies($proxyRefs);
 		$this->referencer->addHostPrototypes($hostPrototypesRefs);
@@ -723,8 +733,10 @@ class CConfigurationImport {
 					$applicationsIds = [];
 
 					foreach ($item['applications'] as $application) {
-						if ($applicationId = $this->referencer->resolveApplication($hostId, $application['name'])) {
-							$applicationsIds[] = $applicationId;
+						$applicationid = $this->referencer->resolveApplication($hostId, $application['name']);
+
+						if ($applicationid) {
+							$applicationsIds[] = $applicationid;
 						}
 						else {
 							throw new Exception(_s('Item "%1$s" on "%2$s": application "%3$s" does not exist.',
@@ -736,7 +748,16 @@ class CConfigurationImport {
 				}
 
 				if (array_key_exists('interface_ref', $item) && $item['interface_ref']) {
-					$item['interfaceid'] = $this->referencer->interfacesCache[$hostId][$item['interface_ref']];
+					$interfaceid = $this->referencer->resolveInterface($hostId, $item['interface_ref']);
+
+					if ($interfaceid) {
+						$item['interfaceid'] = $interfaceid;
+					}
+					else {
+						throw new Exception(_s('Cannot find interface "%1$s" used for item "%2$s" on "%3$s".',
+							$item['interface_ref'], $item['name'], $host
+						));
+					}
 				}
 
 				if (isset($item['valuemap']) && $item['valuemap']) {
@@ -790,6 +811,12 @@ class CConfigurationImport {
 					$item['query_fields'] = $query_fields;
 				}
 
+				foreach ($item['preprocessing'] as &$preprocessing_step) {
+					$preprocessing_step['params'] = implode("\n", $preprocessing_step['parameters']);
+					unset($preprocessing_step['parameters']);
+				}
+				unset($preprocessing_step);
+
 				$itemsId = $this->referencer->resolveItem($hostId, $item['key_']);
 
 				if ($itemsId) {
@@ -937,7 +964,16 @@ class CConfigurationImport {
 				$item['hostid'] = $hostId;
 
 				if (array_key_exists('interface_ref', $item) && $item['interface_ref']) {
-					$item['interfaceid'] = $this->referencer->interfacesCache[$hostId][$item['interface_ref']];
+					$interfaceid = $this->referencer->resolveInterface($hostId, $item['interface_ref']);
+
+					if ($interfaceid) {
+						$item['interfaceid'] = $interfaceid;
+					}
+					else {
+						throw new Exception(_s('Cannot find interface "%1$s" used for discovery rule "%2$s" on "%3$s".',
+							$item['interface_ref'], $item['name'], $host
+						));
+					}
 				}
 
 				unset($item['item_prototypes']);
@@ -977,13 +1013,48 @@ class CConfigurationImport {
 
 				unset($item['master_item']);
 
+				if ($item['overrides']) {
+					foreach ($item['overrides'] as &$override) {
+						foreach ($override['operations'] as &$operation) {
+							if ($operation['operationobject'] == OPERATION_OBJECT_HOST_PROTOTYPE
+									&& array_key_exists('optemplate', $operation)) {
+								foreach ($operation['optemplate'] as &$template) {
+									$templateid = $this->referencer->resolveTemplate($template['name']);
+
+									if (!$templateid) {
+										throw new Exception(_s(
+											'Cannot find template "%1$s" for override "%2$s" of discovery rule "%3$s" on "%4$s".',
+											$template['name'],
+											$override['name'],
+											$item['name'],
+											$host
+										));
+									}
+
+									$template['templateid'] = $templateid;
+
+									unset($template['name']);
+								}
+							}
+						}
+						unset($operation);
+					}
+					unset($override);
+				}
+
+				foreach ($item['preprocessing'] as &$preprocessing_step) {
+					$preprocessing_step['params'] = implode("\n", $preprocessing_step['parameters']);
+					unset($preprocessing_step['parameters']);
+				}
+				unset($preprocessing_step);
+
 				if ($itemId) {
 					$item['itemid'] = $itemId;
 					$itemsToUpdate[] = $item;
 				}
 				else {
 					/*
-					 * The array key "lld_macro_paths" must exist at this point. It is processed by chain convertion.
+					 * The array key "lld_macro_paths" must exist at this point. It is processed by chain conversion.
 					 * Unlike discoveryrule.update method, discoveryrule.create does not allow "lld_macro_paths"
 					 * to be empty.
 					 */
@@ -1029,8 +1100,9 @@ class CConfigurationImport {
 		// process prototypes
 		$prototypes_to_update = [];
 		$prototypes_to_create = [];
-		$hostPrototypesToUpdate = [];
+		$host_prototypes_to_update = [];
 		$hostPrototypesToCreate = [];
+		$ex_group_prototypes_where = [];
 
 		foreach ($allDiscoveryRules as $host => $discoveryRules) {
 			$hostId = $this->referencer->resolveHostOrTemplate($host);
@@ -1064,7 +1136,20 @@ class CConfigurationImport {
 					}
 
 					if (array_key_exists('interface_ref', $prototype) && $prototype['interface_ref']) {
-						$prototype['interfaceid'] = $this->referencer->interfacesCache[$hostId][$prototype['interface_ref']];
+						$interfaceid = $this->referencer->resolveInterface($hostId, $prototype['interface_ref']);
+
+						if ($interfaceid) {
+							$prototype['interfaceid'] = $interfaceid;
+						}
+						else {
+							throw new Exception(_s(
+								'Cannot find interface "%1$s" used for item prototype "%2$s" of discovery rule "%3$s" on "%4$s".',
+								$prototype['interface_ref'],
+								$prototype['name'],
+								$item['name'],
+								$host
+							));
+						}
 					}
 
 					if ($prototype['valuemap']) {
@@ -1125,6 +1210,12 @@ class CConfigurationImport {
 					$prototype['rule'] = ['hostid' => $hostId, 'key' => $item['key_']];
 					$prototype['ruleid'] = $this->referencer->resolveItem($hostId, $item['key_']);
 
+					foreach ($prototype['preprocessing'] as &$preprocessing_step) {
+						$preprocessing_step['params'] = implode("\n", $preprocessing_step['parameters']);
+						unset($preprocessing_step['parameters']);
+					}
+					unset($preprocessing_step);
+
 					if ($prototypeId) {
 						if (!array_key_exists($level, $prototypes_to_update)) {
 							$prototypes_to_update[$level] = [];
@@ -1189,32 +1280,53 @@ class CConfigurationImport {
 					$hostPrototypeId = $this->referencer->resolveHostPrototype($hostId, $itemId, $hostPrototype['host']);
 
 					if ($hostPrototypeId) {
+						if ($hostPrototype['groupPrototypes']) {
+							$ex_group_prototypes_where[] = '('.dbConditionInt('hostid', [$hostPrototypeId]).
+								' AND '.dbConditionString('name',
+									zbx_objectValues($hostPrototype['groupPrototypes'], 'name')
+								).
+							')';
+						}
+
 						$hostPrototype['hostid'] = $hostPrototypeId;
-						$hostPrototypesToUpdate[] = $hostPrototype;
+						$host_prototypes_to_update[] = $hostPrototype;
 					}
 					else {
 						$hostPrototype['ruleid'] = $itemId;
 						$hostPrototypesToCreate[] = $hostPrototype;
 					}
 				}
+			}
+		}
 
-				if (array_key_exists('interface_ref', $item) && $item['interface_ref']) {
-					$item['interfaceid'] = $this->referencer->interfacesCache[$hostId][$item['interface_ref']];
-				}
-				unset($item['item_prototypes']);
-				unset($item['trigger_prototypes']);
-				unset($item['graph_prototypes']);
-				unset($item['host_prototypes']);
+		// Attach existing host group prototype ids.
+		if ($ex_group_prototypes_where) {
+			$db_group_prototypes = DBFetchArray(DBselect(
+				'SELECT group_prototypeid,name,hostid'.
+					' FROM group_prototype'.
+					' WHERE '.implode(' OR ', $ex_group_prototypes_where)
+			));
 
-				$itemsId = $this->referencer->resolveItem($hostId, $item['key_']);
+			if ($db_group_prototypes) {
+				$groups_hash = [];
+				foreach ($db_group_prototypes as $group) {
+					$groups_hash[$group['hostid']][$group['name']] = $group['group_prototypeid'];
+				}
 
-				if ($itemsId) {
-					$item['itemid'] = $itemsId;
-					$itemsToUpdate[] = $item;
-				}
-				else {
-					$itemsToCreate[] = $item;
+				foreach ($host_prototypes_to_update as &$host_prototype) {
+					if (!array_key_exists($host_prototype['hostid'], $groups_hash)) {
+						continue;
+					}
+
+					$hash = $groups_hash[$host_prototype['hostid']];
+					foreach ($host_prototype['groupPrototypes'] as &$group_prototype) {
+						if (array_key_exists($group_prototype['name'], $hash)) {
+							$group_prototype['group_prototypeid'] = $hash[$group_prototype['name']];
+						}
+					}
+					unset($group_prototype, $hash);
 				}
+				unset($host_prototype, $groups_hash);
 			}
 		}
 
@@ -1231,8 +1343,8 @@ class CConfigurationImport {
 		if ($hostPrototypesToCreate) {
 			API::HostPrototype()->create($hostPrototypesToCreate);
 		}
-		if ($hostPrototypesToUpdate) {
-			API::HostPrototype()->update($hostPrototypesToUpdate);
+		if ($host_prototypes_to_update) {
+			API::HostPrototype()->update($host_prototypes_to_update);
 		}
 
 		// refresh prototypes because templated ones can be inherited to host and used in triggers prototypes or graph prototypes
@@ -1770,18 +1882,18 @@ class CConfigurationImport {
 	}
 
 	/**
-	 * Import template screens.
+	 * Import template dashboards.
 	 */
-	protected function processTemplateScreens() {
-		if ($this->options['templateScreens']['updateExisting']
-				|| $this->options['templateScreens']['createMissing']
-				|| $this->options['templateScreens']['deleteMissing']) {
-			$screens = $this->getFormattedTemplateScreens();
-			$screenImporter = new CTemplateScreenImporter($this->options, $this->referencer,
+	protected function processTemplateDashboards() {
+		if ($this->options['templateDashboards']['updateExisting']
+				|| $this->options['templateDashboards']['createMissing']
+				|| $this->options['templateDashboards']['deleteMissing']) {
+			$dashboards = $this->getFormattedTemplateDashboards();
+			$dashboardImporter = new CTemplateDashboardImporter($this->options, $this->referencer,
 				$this->importedObjectContainer
 			);
-			$screenImporter->delete($screens);
-			$screenImporter->import($screens);
+			$dashboardImporter->delete($dashboards);
+			$dashboardImporter->import($dashboards);
 		}
 	}
 
@@ -2502,12 +2614,12 @@ class CConfigurationImport {
 	 *
 	 * @return array
 	 */
-	protected function getFormattedTemplateScreens() {
-		if (!isset($this->formattedData['templateScreens'])) {
-				$this->formattedData['templateScreens'] = $this->adapter->getTemplateScreens();
+	protected function getFormattedTemplateDashboards() {
+		if (!isset($this->formattedData['templateDashboards'])) {
+				$this->formattedData['templateDashboards'] = $this->adapter->getTemplateDashboards();
 		}
 
-		return $this->formattedData['templateScreens'];
+		return $this->formattedData['templateDashboards'];
 	}
 
 	/**
