@@ -198,7 +198,9 @@ $item_form_list
 		(new CVisibilityBox('visible[username]', 'username', _('Original')))
 			->setLabel(_('User name'))
 			->setChecked(isset($data['visible']['username'])),
-		(new CTextBox('username', $data['username']))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
+		(new CTextBox('username', $data['username']))
+			->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
+			->disableAutocomplete()
 	)
 	// Append publickey to item form list.
 	->addRow(
@@ -219,7 +221,9 @@ $item_form_list
 		(new CVisibilityBox('visible[password]', 'password', _('Original')))
 			->setLabel(_('Password'))
 			->setChecked(isset($data['visible']['password'])),
-		(new CTextBox('password', $data['password']))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
+		(new CTextBox('password', $data['password']))
+			->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
+			->disableAutocomplete()
 	);
 
 // Create preprocessing form list.
