@@ -1,3 +1,29 @@
+<?php
+/*
+** Zabbix
+** Copyright (C) 2001-2020 Zabbix SIA
+**
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program; if not, write to the Free Software
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+**/
+
+
+/**
+ * @var CView $this
+ */
+?>
+
 <script type="text/x-jquery-tmpl" id="screenRowTPL">
 <?= (new CRow([
 	(new CCol([
@@ -29,7 +55,7 @@
 	<?= (new CRow([
 			new CCol([
 				(new CTextBox('userGroups[#{usrgrpid}][usrgrpid]', '#{usrgrpid}'))->setAttribute('type', 'hidden'),
-				(new CSpan('#{name}')),
+				(new CSpan('#{name}'))
 			]),
 			new CCol(
 				(new CTag('ul', false, [
@@ -51,6 +77,7 @@
 				(new CButton('remove', _('Remove')))
 					->addClass(ZBX_STYLE_BTN_LINK)
 					->onClick('removeUserGroupShares("#{usrgrpid}");')
+					->removeId()
 			))->addClass(ZBX_STYLE_NOWRAP)
 		]))
 			->setId('user_group_shares_#{usrgrpid}')
@@ -62,7 +89,7 @@
 	<?= (new CRow([
 			new CCol([
 				(new CTextBox('users[#{id}][userid]', '#{id}'))->setAttribute('type', 'hidden'),
-				(new CSpan('#{name}')),
+				(new CSpan('#{name}'))
 			]),
 			new CCol(
 				(new CTag('ul', false, [
@@ -84,6 +111,7 @@
 				(new CButton('remove', _('Remove')))
 					->addClass(ZBX_STYLE_BTN_LINK)
 					->onClick('removeUserShares("#{id}");')
+					->removeId()
 			))->addClass(ZBX_STYLE_NOWRAP)
 		]))
 			->setId('user_shares_#{id}')
@@ -96,7 +124,7 @@
 		$('#clone').click(function() {
 			$('#slideshowid, #delete, #clone, #inaccessible_user').remove();
 			$('#update')
-				.text(<?= CJs::encodeJson(_('Add')) ?>)
+				.text(<?= json_encode(_('Add')) ?>)
 				.attr({id: 'add', name: 'add'});
 
 			$('#form').val('clone');
@@ -107,10 +135,10 @@
 			$('#multiselect_userid_wrapper').show();
 
 			// Set current user as owner.
-			$('#userid').multiSelect('addData', {
+			$('#userid').multiSelect('addData', [{
 				'id': $('#current_user_userid').val(),
 				'name': $('#current_user_fullname').val()
-			});
+			}]);
 
 			$('#name').focus();
 		});
@@ -271,7 +299,8 @@
 			disabled: (slideTable.find('tr.sortable').length < 2),
 			items: 'tbody tr.sortable',
 			axis: 'y',
-			cursor: 'move',
+			containment: 'parent',
+			cursor: 'grabbing',
 			handle: 'div.<?= ZBX_STYLE_DRAG_ICON ?>',
 			tolerance: 'pointer',
 			opacity: 0.6,
